==> libreoffice-4.0.5.2.tar.xz: libreoffice-4.0.5.2/lotuswordpro/source/filter/xfilter/xfdate.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
/*************************************************************************
 * @file
 * Date field with date style.
 ************************************************************************/
#include <string.h>
#include    "xfdate.hxx"

XFDate::XFDate()
{
    m_bFixed = 0;
    memset(&m_aDateTime, 0, sizeof(m_aDateTime));
    m_bValued = sal_False;
}

XFDate::~XFDate()
{

}

void    XFDate::ToXml(IXFStream *pStrm)
{
    IXFAttrList *pAttrList = pStrm->GetAttrList();

    pAttrList->Clear();
    if( !GetStyleName().isEmpty() )
        pAttrList->AddAttribute( A2OUSTR("style:data-style-name"), GetStyleName() );
    if (m_bValued)
        pAttrList->AddAttribute( A2OUSTR("text:date-value"), m_strDate );

    if( m_bFixed )
        pAttrList->AddAttribute( A2OUSTR("text:fixed"), A2OUSTR("true") );

    pStrm->StartElement( A2OUSTR("text:date") );
    if (!m_strText.isEmpty())
        pStrm->Characters(m_strText);
    pStrm->EndElement( A2OUSTR("text:date") );
}

void XFDateStart::ToXml(IXFStream *pStrm)
{
    IXFAttrList *pAttrList = pStrm->GetAttrList();

    pAttrList->Clear();
    if( !GetStyleName().isEmpty() )
        pAttrList->AddAttribute( A2OUSTR("style:data-style-name"), GetStyleName() );
/*  if (m_bValued)
        pAttrList->AddAttribute( A2OUSTR("text:date-value"), DateTimeToOUString(m_aDateTime) );
    if( m_bFixed )
        pAttrList->AddAttribute( A2OUSTR("text:fixed"), A2OUSTR("true") );

    pStrm->StartElement( A2OUSTR("text:date") );
    if (m_strText.getLength()>0)
        pStrm->Characters(m_strText);
*/
    pStrm->StartElement( A2OUSTR("text:date") );
}

void XFDateEnd::ToXml(IXFStream *pStrm)
{
    pStrm->EndElement( A2OUSTR("text:date") );
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_5.4.6.orig.tar.xz: libreoffice-5.4.6/lotuswordpro/source/filter/xfilter/xfdate.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
/*************************************************************************
 * @file
 * Date field with date style.
 ************************************************************************/
#include <string.h>
#include "xfdate.hxx"

XFDate::XFDate()
{
}

XFDate::~XFDate()
{
}

void    XFDate::ToXml(IXFStream *pStrm)
{
    IXFAttrList *pAttrList = pStrm->GetAttrList();

    pAttrList->Clear();
    if( !GetStyleName().isEmpty() )
        pAttrList->AddAttribute( "style:data-style-name", GetStyleName() );

    pStrm->StartElement( "text:date" );
    if (!m_strText.isEmpty())
        pStrm->Characters(m_strText);
    pStrm->EndElement( "text:date" );
}

void XFDateStart::ToXml(IXFStream *pStrm)
{
    IXFAttrList *pAttrList = pStrm->GetAttrList();

    pAttrList->Clear();
    if( !GetStyleName().isEmpty() )
        pAttrList->AddAttribute( "style:data-style-name", GetStyleName() );
/*  if (m_bValued)
        pAttrList->AddAttribute( "text:date-value", DateTimeToOUString(m_aDateTime) );
    if( m_bFixed )
        pAttrList->AddAttribute( "text:fixed", "true" );

    pStrm->StartElement( "text:date" );
    if (m_strText.getLength()>0)
        pStrm->Characters(m_strText);
*/
    pStrm->StartElement( "text:date" );
}

void XFDateEnd::ToXml(IXFStream *pStrm)
{
    pStrm->EndElement( "text:date" );
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
